@@ -1,7 +1,7 @@
 var { interfaces: Ci, utils: Cu, classes: Cc } = Components;
 
 Cu.import("resource://gre/modules/XPCOMUtils.jsm");
-Cu.import("resource://gre/modules/imXPCOMUtils.jsm");
+Cu.import("resource:///modules/imXPCOMUtils.jsm");
 Cu.import("resource://gre/modules/AddonManager.jsm");
 Cu.import("resource://gre/modules/Preferences.jsm");
 
@@ -214,6 +214,8 @@ var TorBirdyPrefs = {
   "browser.cache.memory.enable": false,
   "browser.cache.offline.enable": false,
   "browser.formfill.enable": false,
+  // https://bugs.torproject.org/22944
+  "browser.chrome.site_icons": false,
   "signon.autofillForms": false,
 
   // https://bugs.torproject.org/10367
@@ -272,8 +274,8 @@ var TorBirdyPrefs = {
                                               "--no-comments " +
                                               // We want to force UTF-8 everywhere
                                               "--display-charset utf-8 " +
-                                              // We want to ensure that Enigmail is proxy aware even when it runs gpg in a shell
-                                              "--keyserver-options http-proxy=socks5h://127.0.0.1:9150 ",
+                                              // Set additional keyserver options
+                                              "--keyserver-options no-auto-key-retrieve ",
                                             
   // The default key server should be a hidden service; use the Tor OnionBalance hidden service pool (https://sks-keyservers.net/overview-of-pools.php#pool_tor)
   "extensions.enigmail.keyserver": "hkp://jirk5u4osbsr34t5.onion",
@@ -389,12 +391,14 @@ var TorBirdyOldPrefs = [
   "network.proxy.http",
 ]
 
-// sanitizeDateHeaders()
-// Run this function to make sure that the Date header in a new message
-// is rounded down to the nearest minute.
-function sanitizeDateHeaders() {
+// sanitizeHeaders()
+// Sanitize the "Date" and "Content-Language" headers.
+function sanitizeHeaders() {
   // Import the jsmime module that is used to generate mail headers.
   let { jsmime } = Cu.import("resource:///modules/jsmime.jsm");
+  // Date
+  // Run this function to make sure that the Date header in a new message
+  // is rounded down to the nearest minute.
   // Inject our own structured encoder to the default header emitter,
   // to override the default Date encoder with a rounded-down version.
   jsmime.headeremitter.addStructuredEncoder("Date", function (date) {
@@ -408,6 +412,14 @@ function sanitizeDateHeaders() {
     // We replace the "GMT" symbol with "+0000" because it is preferred.
     this.addText(roundedDate.toUTCString().replace(/GMT$/, "+0000"), false);
   });
+  // Content-Language
+  // Also set the Content-Language to "en-US" to prevent leaking the user's
+  // default dictionary. Reported in https://bugs.torproject.org/22484 and
+  // discussed in Section 4 of RFC 3282.
+  // Thunderbird bug: https://bugzilla.mozilla.org/show_bug.cgi?id=1370217
+  jsmime.headeremitter.addStructuredEncoder("Content-Language", function (locale) {
+    this.addText("en-US", false);
+  });
 }
 
 function TorBirdy() {
@@ -437,9 +449,8 @@ function TorBirdy() {
 
   this.setAccountPrefs();
   this.setPrefs();
-  sanitizeDateHeaders();
+  sanitizeHeaders();
 
-  dump("TorBirdy registered!\n");
 }
 
 TorBirdy.prototype = {
@@ -471,7 +482,6 @@ TorBirdy.prototype = {
   onUninstalling: function(addon, needsRestart) {
     this.onStateChange();
     if (addon.id == TB_ID) {
-      dump("TorBirdy uninstall requested\n");
       this._uninstall = true;
       this.resetUserPrefs();
     }
@@ -480,7 +490,6 @@ TorBirdy.prototype = {
   onOperationCancelled: function(addon) {
     this.onStateChange();
     if (addon.id == TB_ID) {
-      dump("Uninstall requested cancelled\n");
       this._uninstall = false;
       this.setPrefs();
     }
@@ -491,14 +500,12 @@ TorBirdy.prototype = {
   },
 
   resetUserPrefs: function() {
-    dump("Resetting user preferences to default\n");
     // Clear the Thunderbird preferences we changed.
     for (let each in TorBirdyPrefs) {
       this.prefs.clearUserPref(each);
     }
 
     // Restore the older proxy preferences that were set prior to TorBirdy's install.
-    dump("Restoring proxy settings\n");
     for (let i = 0; i < TorBirdyOldPrefs.length; i++) {
       var oldPref = TorBirdyOldPrefs[i];
       var setValue = kRestoreBranch + oldPref;
